pub struct MessagingRequestReply { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world messaging-request-reply.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
MessagingRequestReply::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a [
MessagingRequestReplyPre] ahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then uses [MessagingRequestReplyPre::instantiate] to create aMessagingRequestReply. -
If you’ve instantiated the instance yourself already then you can use
MessagingRequestReply::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl MessagingRequestReply
impl MessagingRequestReply
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<MessagingRequestReply>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<MessagingRequestReply>
Convenience wrapper around [MessagingRequestReplyPre::new] and
[MessagingRequestReplyPre::instantiate].
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<MessagingRequestReply>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<MessagingRequestReply>
Convenience wrapper around [MessagingRequestReplyIndices::new] and
[MessagingRequestReplyIndices::load].
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<MessagingRequestReply>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<MessagingRequestReply>where
_T: Send,
Convenience wrapper around [MessagingRequestReplyPre::new] and
[MessagingRequestReplyPre::instantiate_async].
pub fn add_to_linker<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> D::Data<'_>, ) -> Result<()>
pub fn wasi_messaging_incoming_handler(&self) -> &Guest